# equation constants

# gas diffusivity
CONST_EQ_GAS_DIFFUSIVITY = {
    "Chapman-Enskog": 1,
    "Wilke-Lee": 2
}

# gas viscosity
CONST_EQ_GAS_VISCOSITY = {
    "eq1": 1,
    "eq2": 2
}

# sherwood number
CONST_EQ_Sh = {
    "Frossling": 1,
    "Rosner": 2,
    "Garner-and-Keey": 3
}
